#
# spec file for package gmavenplus-plugin
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gmavenplus-plugin
Version:        1.13.1
Release:        1.7
Summary:        Integrates Groovy into Maven projects
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://groovy.github.io/GMavenPlus/
Source0:        https://github.com/groovy/GMavenPlus/archive/%{version}.tar.gz
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  mvn(jline:jline)
BuildRequires:  mvn(org.apache.ant:ant)
BuildRequires:  mvn(org.apache.ivy:ivy)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.shared:file-management)
BuildRequires:  mvn(org.apache.maven:maven-archiver)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.codehaus.plexus:plexus-component-metadata)
BuildRequires:  mvn(org.fusesource.jansi:jansi)
BuildArch:      noarch

%description
GMavenPlus is a rewrite of GMaven, a Maven plugin
that allows you to integrate Groovy into your
Maven projects.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n GMavenPlus-%{version}

%pom_remove_plugin :maven-clean-plugin
%pom_remove_plugin :maven-dependency-plugin
%pom_remove_plugin :maven-help-plugin
%pom_remove_plugin :animal-sniffer-maven-plugin
%pom_remove_plugin :jacoco-maven-plugin
%pom_remove_plugin :maven-source-plugin
%pom_remove_plugin :maven-deploy-plugin
%pom_remove_plugin :maven-site-plugin
%pom_remove_plugin :maven-enforcer-plugin

%pom_xpath_remove "pom:build/pom:extensions"
%pom_xpath_remove "pom:plugin[pom:artifactId='maven-javadoc-plugin']/pom:executions"

# Mockito cannot mock this class: class org.codehaus.gmavenplus.mojo.AbstractGroovyMojoTest$TestGroovyMojo
rm -r src/test/java/org/codehaus/gmavenplus/mojo/AbstractGroovyMojoTest.java

# Convert from dos to unix line ending
dos2unix README.markdown

%{mvn_file} : %{name}

%build
%{mvn_build} -f -- -Pnonindy -Dsource=7

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%doc README.markdown
%license LICENSE.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt

%changelog
* Fri Dec 17 2021 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 1.13.1
- Changes in 1.13.1
  * Bugs
    + [#203] Using bindAllProjectProperties and
    bindSessionUserOverrideProperties together can cause an NPE.
- Changes in 1.13.0
  * Enhancements
    + [#196] Add support for targetting Java 17.
    + [#198] Add support for targetting Java 18.
    + [#188/#193] Update Ant from 1.10.8 to 1.10.11.
- Changes in 1.12.1
  * Bugs
    +  [#186] Certain AST transformations had classloader issues
    because 1.12.0 was no longer setting the context classloader.
  * Enhancements
    + Update Jansi to 2.x.
  * Potentially breaking changes
    + The Jansi upgrade should generally be compatible, but could
    cause issues with scripts that were using Jansi 1.x specific
    classes.
- Changes in 1.12.0
  * Bugs
    + [#183] The classloader project dependencies are loaded onto is
    reused between modules, so each module was a superset of all
    modules that preceded it. Also, the console, execute, and
    shell mojos didn't pass the classloader to use into the
    instantiated GroovyConsole/GroovyShell, so it accidentally was
    using the plugin classloader, even when configured to use
    PROJECT_ONLY classpath.
  * Potentially breaking changes
    + This should be a non-breaking change (except for unusual
    situations that were relying on the previous incorrect
    behavior). However, since it's a significant change, I'm
    bumping the version by more than just the patch version.
  * Notes
    + This potentially runs slower than before, since a new
    classloader is instantiated each execution, rather than
    resuing the same classloader, so the classes referenced will
    have to be reinitialized.
- Changes in 1.11.1
  * Bugs
    + Fixes IllegalArgumentException when consoleScript parameter
    was loaded from POM rather than command line property.
- Changes in 1.11.0
  * Enhancements
    + Change JDK compatibility check to also account for Java 16.
    + Some tweaks for Groovy 4 (most notably, invokedynamic is
    enabled by default for Groovy 4 and cannot be disabled).
    + New parameter (attachGroovyDocAnnotation) to enable attaching
    GroovyDoc annotation.
    + New parameter (parallelParsing) to enable parallel parsing
    (enabled by default with Groovy 4).
    + Remove previewFeatures parameter from stub generation goals,
    since it's not used there.
  * Potentially breaking changes
    + If you were using the previewFeatures parameter without also
    including a compilation goal that would make that config
    valid, the build will fail because it's no longer a valid
    parameter. The fix would be to move that configuration to the
    appropriate execution(s).
- Changes in 1.10.1
  * Enhancements
    + Ability to override classes used to generate GroovyDoc (#91)
    + Ability to override GStringTemplates used for GroovyDoc (#105)
    + Ability to bind overridden properties (by binding project
    properties and/or session user properties) (#72)
    + Ability to load a script when launching GroovyConsole (#165)
- Changes in 1.10.0
  * Enhancements
    + Change default GroovyDoc jar artifact type to javadoc, so its
    extension gets set to "jar" by the artifact handler instead of
    "groovydoc" by the default handler logic which uses the type
    for the extension in the case of unknown types (#151).
  * Potentially breaking changes
    + GroovyDoc jars and test GroovyDoc jars will now be of type
    "javadoc" and have extension "jar".  Rather than type and
    extension "groovydoc".  If you do not wish to transition to
    this new behavior, set the new artifactType or
    testArtifactType property to "groovydoc" to revert to the
    previous behavior.
  * Notes
    + While the artifact type of GroovyDoc jars has changed, the
    Maven classifier has not. It remains "groovydoc", and you can
    still override that, just as before.
- Changes in 1.9.1
  * Enhancements
    + Add a property to skip script execution (#162)
- Changes in 1.9.0
  * Enhancements
    + Support for Java 14 (#152).
    + Support for Java 15 (#153).
    + Add skipBytecodeCheck property and parameter, so if a Java
    version comes out the plugin doesn't recognize, you can use it
    without having to wait for an update.
    + Use groovy.ant.AntBuilder instead of groovy.util.AntBuilder
    (if available).
  * Potentially breaking changes
    + maven.groovydoc.skip property was renamed to skipGroovydoc so
    it matches the pattern of the other properties and won't seem
    to imply it's a property for a standard Maven plugin.
    + Using groovy.ant.AntBuilder instead of groovy.util.AntBuilder
    (when available on classpath).
    + Bundling Ant 1.10.7 instead of 1.10.5.
    + Bundling Ivy 2.5.0 instead of 2.4.0.
  * Notes
    + Now officially requires Java 7 instead of 6. This is not a
    breaking change, however, since this was actually already
    required because of plexus-classworlds. This just wasn't
    discovered until an enforcer rule was added to check bytecode
    versions of dependencies.
- Changes in 1.8.1
  * Bugs
    + #147 Change sourcesets internal storage from HashSet to
    TreeSet, to avoid unpredictable Groovy compiler output on
    certain filesystems.
    + #145 Disable system exits by default, to avoid potential
    thread safety issues.
  * Potentially breaking changes
    + #145 Changes the default of not allowing System.exits to
    allowing them.
- Changes in 1.8.0
  * Enhancements
    + Allow for invocation using only project classpath (#140).
    This is accomplished with
    <includeClasspath>PLUGIN_ONLY</includeClasspath>.
  * Potentially breaking changes
    + #140 If you were using useSharedClasspath before, you will
    need to replace it with new values. In most cases, this would
    be
    +---------------------+--------------------+
    | usedSharedClasspath | includeClasspath   |
    +---------------------+--------------------+
    | true                | PROJECT_AND_PLUGIN |
    | false               | PROJECT_ONLY       |
    +---------------------+--------------------+
    + Another notable difference is that when using this new
    configuration parameter in compile, compileTests,
    generateStubs, or generateTestStubs goals, now also uses the
    configurator to add the project dependencies to the classpath
    with the plugin's dependencies. Previously, this only happened
    in the goals other than the ones mentioned.
- Changes in 1.7.1
  * Bugs
    + Fix that Groovy 3.0.0-alpha-5 was actually released as
    3.0.0-beta-1 (#133)
  * Enhancements
    + Support Java preview features (#125)
    + New goals to create GroovyDoc jars (#124)
    + Use the new "groovy.console.ui.Console" package, if available,
    fall back to "groovy.ui.Console" (#136)
- Changes in 1.7.0
  * Bugs
    + #131 Fix executing script from URL in Groovy older than 1.7.0
    + #120 Use unique configuration names for every mojo, so goals
    don't conflict
  * Enhancements
    + #122 Support Java 13
  * Potentially breaking changes
    + #120 corrects an inadvertent breaking change made in 1.6.0
    with #31/#58. Here are those changes: +--------------------------+----------------------+--------------------------+
    | 1.5                      | 1.6                  | 1.7                      |
    +-------------------------------------+--------------------------+----------------------+--------------------------+
    | addStubSources                      | stubsOutputDirectory     | outputDirectory      | stubsOutputDirectory     |
    | addTestStubSources                  | testStubsOutputDirectory | outputDirectory      | testStubsOutputDirectory |
    | compileTests/testCompile            | testOutputDirectory      | outputDirectory      | testOutputDirectory      |
    | generateStubs                       | stubsOutputDirectory     | outputDirectory      | stubsOutputDirectory     |
    | generateTestStubs/testGenerateStubs | testStubsOutputDirectory | outputDirectory      | testStubsOutputDirectory |
    | groovydocTests/testGroovydoc        | groovydocJavaSources     | groovydocJavaSources | testGroovydocJavaSources |
    | removeStubs                         | stubsOutputDirectory     | outputDirectory      | stubsOutputDirectory     |
    | removeTestStubs                     | testStubsOutputDirectory | outputDirectory      | testStubsOutputDirectory |
    +-------------------------------------+--------------------------+----------------------+--------------------------+
    + In addition, unused parameters have been removed:
    = addSources
  - > skipTests
  - > testSources
    = addStubSources
  - > skipTests
  - > sources
  - > testSources
    = addTestSources
  - > outputDirectory
  - > skipTests
  - > sources
    = addTestStubSources
  - > sources
  - > testSources
    = compile
  - > skipTests
  - > testSources
    = compileTests
  - > sources
    = console
  - > skipTests
    = execute
  - > skipTests
    = generateStubs
  - > skipTests
  - > testSources
    = generateTestStubs
  - > sources
    = groovydoc
  - > skipTests
  - > testSources
  - > testGroovyDocOutputDirectory
    = groovydocTests
  - > skipTests
  - > sources
    = removeStubs
  - > skipTests
  - > sources
  - > testSources
    = removeTestStubs
  - > sources
  - > testSources
    = shell
  - > skipTests
    + Lastly, addTestStubSources and removeTestStubs now respect the
    skipTests flag, for consistency.
- Changes in 1.6.3
  * Enhancements
    + Ability to use Groovy from plugin dependencies (creates a
    single classpath with plugin and project dependencies)
    (#64 & #86)
    + Support for Java 13 bytecode (#123)
    + Log executed scripts (#119)
    + Log message from exception cause (#112)
- Changes in 1.6.2
  * Bugs
    + Fixed that could error saying no Groovy dependency when it
    shouldn't because no Groovy sources exist (ef3a3d5).
  * Enhancements
    + Support for Java 10 bytecode (#104)
    + Support for Java 11 bytecode (#106)
- Changes in 1.6.1
  * Bugs
    + Fixed that was logging Groovy version as not supporting config
    script if config script file didn't exist
    + Fixed NPE when calling mojo without Groovy dependency
    + Fixed that was logging compile classpath instead of test
    classpath during test GroovyDoc generation
- Changes in 1.6
  * Bugs
    + [38] - Compilation doesn't allow indy back far enough (thanks
    for pointing this out Pascal Schumacher!)
  * Enhancements
    + [36] - Allow script files to be executed as filenames as well
    as URLs (see Significant changes of note for an example)
    + [41] - Verify Groovy version supports target bytecode (See
    Potentially breaking changes for a description)
    + [46] - Remove scriptExtensions config option
    + [31/58] - Goals not consistantly named / IntelliJ improperly
    adding stub directories to sources
    + [61] - You can now skip Groovydoc generation with new
    skipGroovyDoc property (Thanks rvenutolo!)
    + [45] - GROOVY-7423 (JEP 118) Support (requires Groovy
    2.5.0-alpha-1 or newer and enabled with new parameters boolean
    property)
  * Potentially breaking changes
    + 46 will break your build if you are using scriptExtensions.
    But the fix is simple, just the delete the configuration
    option and GMavenPlus will automatically do the right thing.
    + 41 will break your build if you were passing an invalid target
    bytecode. GMavenPlus will no longer allow Groovy to silently
    default to 1.4 or 1.5. It will verify that the bytecode is
    supported by your Groovy version (that is, the option exists
    in org.codehaus.groovy.control.CompilerConfiguration), and
    fail if it isn't.
    + 58 will require renaming goals testGenerateStubs to
    generateTestStubs and testCompile to compileTests. IntelliJ
    has hard-coded the goal names in their plugin, and these names
    will make IntelliJ work with both GMaven and GMavenPlus.
    + In order to support using the latest Maven plugins (and to
    make GMavenPlus easier to maintain), GMavenPlus now requires
    Java 6 or newer and Maven 3.0.1 or newer (previously was
    Java 5 or newer and Maven 2.2.1 or newer).
    + Due to an unintended side-effect of logging order change,
    adding a GMavenPlus goal without Groovy dependency will fail
    if there are no Groovy sources to use that goal with. If this
    is an issue for you, please let me know, and I'll consider
    reversing the order back.
    + testStubsOutputDirectory and stubsOutputDirectory
    inadvertently got renamed to outputDirectory, which conflicts
    with the configuration in the compile and compileTests goals.
    You may need to setup separate executions with separate
    configurations for each if you need to set that configuration
    option.
  * Notes
    + You can now use this syntax for executing scripts
    <script>${project.basedir}/src/main/resources/groovyScripts/helloWorld.groovy</script>
    in addition to the original style of
    <script>file:///${project.basedir}/src/main/resources/groovyScripts/helloWorld.groovy</script>
    + This will be the last release that doesn't follow semantic
    versioning conventions.
* Sun Nov 24 2019 Fridrich Strba <fstrba@suse.com>
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Tue Nov 12 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of gmavenplus-plugin 1.5
